"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createOAuth2BrowserPersistence = exports.createOAuth2SessionPersistence = exports.createOAuth2MemoryPersistence = void 0;
/**
 * Creates an OAuth 2 persistence layer using memory.
 */
function createOAuth2MemoryPersistence() {
    return {
        load() {
            return undefined;
        },
        save() { },
    };
}
exports.createOAuth2MemoryPersistence = createOAuth2MemoryPersistence;
/**
 * Creates an OAuth 2 persistence layer using sessionStorage.
 */
function createOAuth2SessionPersistence(sessionKey = '$piral_oauth2_info') {
    return {
        load() {
            const content = sessionStorage.getItem(sessionKey);
            if (typeof content === 'string') {
                try {
                    return JSON.parse(content);
                }
                catch {
                    console.error('Found invalid data in the OAuth 2 session storage key. Skipped.');
                }
            }
            return undefined;
        },
        save(info) {
            sessionStorage.setItem(sessionKey, JSON.stringify(info));
        },
    };
}
exports.createOAuth2SessionPersistence = createOAuth2SessionPersistence;
/**
 * Creates an OAuth 2 persistence layer using localStorage.
 */
function createOAuth2BrowserPersistence(localKey = '$piral_oauth2_info') {
    return {
        load() {
            const content = localStorage.getItem(localKey);
            if (typeof content === 'string') {
                try {
                    return JSON.parse(content);
                }
                catch {
                    console.error('Found invalid data in the OAuth 2 local storage key. Skipped.');
                }
            }
            return undefined;
        },
        save(info) {
            localStorage.setItem(localKey, JSON.stringify(info));
        },
    };
}
exports.createOAuth2BrowserPersistence = createOAuth2BrowserPersistence;
//# sourceMappingURL=utils.js.map